@@ -3,7 +3,6 @@ Copyright © 2025 Omnissa, LLC.
 """
 
 import json
-import os
 from datetime import datetime, timedelta
 
 import yumako
@@ -36,9 +35,10 @@ def create_pool_html_report(org_id: str, resource_id: str, resource_type: str, t
             recommendations = {"recommendations": []}
 
         # Generate HTML content
+        formatted_resource_type = _format_resource_type_with_template(resource_type, template_info)
         html_content = _get_pool_html_template(
             org_name=org_name,
-            resource_type=resource_type,
+            resource_type=formatted_resource_type,
             resource_id=resource_id,
             generation_date=datetime.now().strftime("%Y-%m-%d %H:%M:%S"),
             template_info=template_info,
@@ -110,6 +110,16 @@ def prepare_vm_utilization_chart_data(template_info: dict) -> dict:
         # Get Utilized Capacity data
         utilized_capacity = history.get("consumedSessions", [])
 
+        # Handle MULTI_SESSION templates by converting sessions to VM-equivalent
+        template = template_info.get("template", {})
+        template_type = template.get("templateType", "")
+        sessions_per_vm = 1
+        if template_type == "MULTI_SESSION":
+            sessions_per_vm = template.get("sessionsPerVm", 1)
+            # Convert sessions to VM-equivalent capacity
+            if sessions_per_vm > 0:
+                utilized_capacity = [sessions / sessions_per_vm for sessions in utilized_capacity]
+
         # Ensure all data arrays have the same length
         powered_on_vms = powered_on_vms[:data_length]
         utilized_capacity = utilized_capacity[:data_length]
@@ -139,6 +149,29 @@ def prepare_vm_utilization_chart_data(template_info: dict) -> dict:
     }
 
 
+def _format_resource_type_with_template(resource_type: str, template_info: dict = None) -> str:
+    """
+    Format resource type to include template type for pools.
+
+    Args:
+        resource_type: Original resource type (e.g., "pool", "edge", "uag")
+        template_info: Template information containing template type
+
+    Returns:
+        str: Formatted resource type (e.g., "Pool(MULTI_SESSION)", "Pool(FLOATING)")
+    """
+    if not template_info or resource_type.lower() != "pool":
+        return resource_type.title()
+
+    template = template_info.get("template", {})
+    template_type = template.get("templateType", "")
+
+    if template_type:
+        return f"Pool({template_type})"
+    else:
+        return "Pool"
+
+
 def _format_json_to_text(json_data, indent=2):
     """Format JSON data to readable text (matching pdf_utils.py function)."""
     if not json_data:
@@ -252,8 +285,8 @@ def _get_pool_html_template(
                     color: '#007acc'
                 }},
                 itemStyle: {{
-                    color: '#007acc'   
-                 }},         
+                    color: '#007acc'
+                 }},
                 data: {chart_data['provisioned_vms']}
             }},
             {{
@@ -268,8 +301,8 @@ def _get_pool_html_template(
                     color: '#dc3545'
                 }},
                 itemStyle: {{
-                    color: '#dc3545'   
-                }},         
+                    color: '#dc3545'
+                }},
                 data: {chart_data['powered_on_vms']}
             }},
             {{
@@ -284,8 +317,8 @@ def _get_pool_html_template(
                     color: '#28a745'
                 }},
                 itemStyle: {{
-                    color: '#28a745'   
-                }},         
+                    color: '#28a745'
+                }},
                 data: {chart_data['utilized_capacity']}
             }}
         """
@@ -424,17 +457,17 @@ def _get_pool_html_template(
         <div class="header">
             <h1>Horizon Cloud Next-gen Advisor Report</h1>
         </div>
-        
+
         <div class="metadata">
             <p><strong>Generated on:</strong> {{generation_date}}</p>
             <p><strong>Organization:</strong> {{org_name}}</p>
             <p><strong>Resource Type:</strong> {{resource_type}}</p>
             <p><strong>Resource ID:</strong> {{resource_id}}</p>
         </div>
-        
+
         <div class="section">
             <h2>Part 1: Horizon Cloud Next-gen Usage Insights</h2>
-            
+
             <h3>Summary Information</h3>
             <table>
                 <tr>
@@ -443,18 +476,18 @@ def _get_pool_html_template(
                 </tr>
                 {{summary_html}}
             </table>
-            
+
             <h3>Usage Metrics</h3>
             <table>
                 {{usage_table_html}}
             </table>
         </div>
-        
+
         <div class="section">
             <h2>VM Utilization</h2>
             <div id="vm-utilization-chart" class="chart-container"></div>
         </div>
-        
+
         <div class="section">
             <h2>Part 2: Recommendation Actions</h2>
             <table>
@@ -468,7 +501,7 @@ def _get_pool_html_template(
             </table>
         </div>
     </div>
-    
+
     <script>
         window.addEventListener('DOMContentLoaded', function () {
             var chartDom = document.getElementById('vm-utilization-chart');
@@ -662,12 +695,12 @@ def _get_org_html_template(org_name: str, generation_date: str, all_recommendati
         <div class="header">
             <h1>Horizon Cloud Next-gen Organization Advisor Report</h1>
         </div>
-        
+
         <div class="metadata">
             <p><strong>Generated on:</strong> {{generation_date}}</p>
             <p><strong>Organization:</strong> {{org_name}}</p>
         </div>
-        
+
         <div class="recommendations">
             {{recommendations_html}}
         </div>
