@@ -2,6 +2,7 @@
 Copyright © 2025 Omnissa, LLC.
 """
 
+# Standard library imports
 import datetime
 import io
 import json
@@ -9,6 +10,7 @@ import os
 import tempfile
 import time
 
+# Third-party imports
 import click
 import matplotlib.dates as mdates
 import matplotlib.pyplot as plt
@@ -18,11 +20,35 @@ from reportlab.lib.styles import ParagraphStyle, getSampleStyleSheet
 from reportlab.lib.units import inch
 from reportlab.platypus import Image, LongTable, Paragraph, SimpleDocTemplate, Spacer, Table, TableStyle
 
-from hcs_cli.cmds.advisor.advisor_utils import calculate_usage_metrics, create_report_file, get_template_info
+# Local imports
+from hcs_cli.cmds.advisor.advisor_utils import calculate_usage_metrics
 from hcs_cli.cmds.advisor.recommendation_engine import generate_recommendations
 from hcs_cli.service.org_service import details
 
 
+def _format_resource_type_with_template(resource_type: str, template_info: dict = None) -> str:
+    """
+    Format resource type to include template type for pools.
+
+    Args:
+        resource_type: Original resource type (e.g., "pool", "edge", "uag")
+        template_info: Template information containing template type
+
+    Returns:
+        str: Formatted resource type (e.g., "Pool(MULTI_SESSION)", "Pool(FLOATING)")
+    """
+    if not template_info or resource_type.lower() != "pool":
+        return resource_type.title()
+
+    template = template_info.get("template", {})
+    template_type = template.get("templateType", "")
+
+    if template_type:
+        return f"Pool({template_type})"
+    else:
+        return "Pool"
+
+
 def _format_template_value(value):
     """Format template value to prevent excessive size."""
     if isinstance(value, (str, int, float, bool)):
@@ -60,29 +86,6 @@ def _format_template_value(value):
     return str(value)
 
 
-def _format_meta_data(meta_data):
-    """Format meta data to be more concise and readable."""
-    if not meta_data:
-        return "No meta data available"
-
-    # Extract and format key metrics
-    metrics = []
-    if "history" in meta_data:
-        history = meta_data["history"]
-        if "startTimestamp" in history:
-            start_time = datetime.datetime.fromtimestamp(history["startTimestamp"] / 1000)
-            metrics.append(f"History Start: {start_time.strftime('%Y-%m-%d %H:%M:%S')}")
-            len_history = len(history["provisionedVms"])
-            end_time = start_time + datetime.timedelta(seconds=len_history * meta_data["timeslotMs"] / 1000)
-            metrics.append(f"History End: {end_time.strftime('%Y-%m-%d %H:%M:%S')}")
-            duration = end_time - start_time
-            metrics.append(f"History Duration: {duration}")
-    if "timeslotMs" in meta_data:
-        timeslot_minutes = meta_data["timeslotMs"] / 60000
-        metrics.append(f"Time Slot: {timeslot_minutes} minutes")
-    return "\n".join(metrics)
-
-
 def _get_values(data, key):
     """Helper function to get values from either dictionary or list format."""
     values = data[key]
@@ -137,7 +140,8 @@ def create_pool_pdf_report(org_id: str, resource_id: str, resource_type: str, te
         content.append(Paragraph("Horizon Cloud Next-gen Advisor Report", title_style))
         content.append(Paragraph(f"Generated on: {datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')}", normal_style))
         content.append(Paragraph(f"Organization: {org_name}", normal_style))
-        content.append(Paragraph(f"Resource Type: {resource_type}", normal_style))
+        formatted_resource_type = _format_resource_type_with_template(resource_type, template_info)
+        content.append(Paragraph(f"Resource Type: {formatted_resource_type}", normal_style))
         content.append(Paragraph(f"Resource ID: {resource_id}", normal_style))
         content.append(Spacer(1, 20))
 
@@ -145,12 +149,11 @@ def create_pool_pdf_report(org_id: str, resource_id: str, resource_type: str, te
         content.append(Paragraph("Part 1: Horizon Cloud Next-gen Usage Insights", heading_style))
         content.append(Spacer(1, 30))
         if template_info:
-            meta_data = []
+            # Process other template data (excluding meta which is now handled separately)
             other_data = []
             for key, value in template_info.items():
                 if key == "meta":
-                    formatted_value = _format_meta_data(value)
-                    meta_data.append([key, formatted_value])
+                    continue  # Skip meta as it's handled in Summary Information table
                 elif isinstance(value, (dict, list)) and len(str(value)) > 1000:
                     continue
                 else:
@@ -179,30 +182,87 @@ def create_pool_pdf_report(org_id: str, resource_id: str, resource_type: str, te
                 )
                 content.append(other_table)
                 content.append(Spacer(1, 20))
-            if meta_data:
-                content.append(Paragraph("Summary Information", heading_style))
-                meta_table = LongTable(meta_data, colWidths=[3 * inch, 6 * inch])
-                meta_table.setStyle(
-                    TableStyle(
-                        [
-                            ("BACKGROUND", (0, 0), (-1, 0), colors.grey),
-                            ("TEXTCOLOR", (0, 0), (-1, 0), colors.whitesmoke),
-                            ("ALIGN", (0, 0), (-1, -1), "LEFT"),
-                            ("VALIGN", (0, 0), (-1, -1), "MIDDLE"),
-                            ("FONTNAME", (0, 0), (-1, 0), "Helvetica-Bold"),
-                            ("FONTSIZE", (0, 0), (-1, 0), 12),
-                            ("BOTTOMPADDING", (0, 0), (-1, 0), 12),
-                            ("BACKGROUND", (0, 1), (-1, -1), colors.beige),
-                            ("TEXTCOLOR", (0, 1), (-1, -1), colors.black),
-                            ("FONTNAME", (0, 1), (-1, -1), "Helvetica"),
-                            ("FONTSIZE", (0, 1), (-1, -1), 10),
-                            ("GRID", (0, 0), (-1, -1), 1, colors.black),
-                            ("ROWPADDING", (0, 0), (-1, -1), 6),
-                        ]
-                    )
+            # Add Summary Information table
+            content.append(Paragraph("Summary Information", heading_style))
+
+            # Prepare summary data similar to HTML report
+            summary_data = []
+            if template_info and "meta" in template_info:
+                meta_data = template_info["meta"]
+                history = meta_data.get("history", {})
+                start_timestamp = history.get("startTimestamp")
+                timeslot_ms = meta_data.get("timeslotMs", 0)
+
+                if start_timestamp and "provisionedVms" in history:
+                    start_date = datetime.datetime.fromtimestamp(start_timestamp / 1000).strftime("%Y-%m-%d %H:%M:%S")
+
+                    # Calculate end timestamp from data length
+                    len_history = len(history["provisionedVms"])
+                    end_timestamp = start_timestamp + (len_history * timeslot_ms)
+                    end_date = datetime.datetime.fromtimestamp(end_timestamp / 1000).strftime("%Y-%m-%d %H:%M:%S")
+
+                    # Calculate duration
+                    duration_seconds = (end_timestamp - start_timestamp) / 1000
+                    duration_days = duration_seconds / (24 * 60 * 60)
+
+                    # Format timeslot
+                    timeslot_minutes = timeslot_ms / (1000 * 60)
+
+                    summary_data = [
+                        ["Field", "Value"],
+                        ["History Start", start_date],
+                        ["History End", end_date],
+                        ["History Duration", f"{duration_days:.0f} days"],
+                        ["Time Slot", f"{timeslot_minutes:.1f} minutes"],
+                    ]
+                else:
+                    # Fallback when required data is not available
+                    timeslot_minutes = timeslot_ms / (1000 * 60)
+                    summary_data = [
+                        ["Field", "Value"],
+                        ["History Start", "Not available"],
+                        ["History End", "Not available"],
+                        ["History Duration", "Not available"],
+                        ["Time Slot", f"{timeslot_minutes:.1f} minutes"],
+                    ]
+            else:
+                # Fallback when no meta data is available
+                summary_data = [
+                    ["Field", "Value"],
+                    ["History Start", "No data available"],
+                    ["History End", "No data available"],
+                    ["History Duration", "No data available"],
+                    ["Time Slot", "No data available"],
+                ]
+
+            # Convert table data to Paragraphs for word wrapping
+            summary_data_wrapped = []
+            for row in summary_data:
+                wrapped_row = [Paragraph(str(cell), normal_style) for cell in row]
+                summary_data_wrapped.append(wrapped_row)
+
+            summary_table = Table(summary_data_wrapped, colWidths=[3.5 * inch, 3.5 * inch])
+            summary_table.setStyle(
+                TableStyle(
+                    [
+                        ("BACKGROUND", (0, 0), (-1, 0), colors.grey),
+                        ("TEXTCOLOR", (0, 0), (-1, 0), colors.whitesmoke),
+                        ("ALIGN", (0, 0), (-1, -1), "LEFT"),
+                        ("VALIGN", (0, 0), (-1, -1), "MIDDLE"),
+                        ("FONTNAME", (0, 0), (-1, 0), "Helvetica-Bold"),
+                        ("FONTSIZE", (0, 0), (-1, 0), 12),
+                        ("BOTTOMPADDING", (0, 0), (-1, 0), 12),
+                        ("BACKGROUND", (0, 1), (-1, -1), colors.beige),
+                        ("TEXTCOLOR", (0, 1), (-1, -1), colors.black),
+                        ("FONTNAME", (0, 1), (-1, -1), "Helvetica"),
+                        ("FONTSIZE", (0, 1), (-1, -1), 10),
+                        ("GRID", (0, 0), (-1, -1), 1, colors.black),
+                        ("ROWPADDING", (0, 0), (-1, -1), 6),
+                    ]
                 )
-                content.append(meta_table)
-                content.append(Spacer(1, 20))
+            )
+            content.append(summary_table)
+            content.append(Spacer(1, 20))
 
         # Add usage metrics table
         if template_info and "meta" in template_info:
@@ -211,21 +271,21 @@ def create_pool_pdf_report(org_id: str, resource_id: str, resource_type: str, te
                 usage_data = calculate_usage_metrics(template_info)
             else:
                 usage_data = [
-                    ["Metric", "Value", "Status"],
-                    ["Allocated VMs Hours", "N/A", "N/A"],
-                    ["Powered-on VMs Hours", "N/A", "N/A"],
-                    ["Utilized VMs Hours", "N/A", "N/A"],
-                    ["Idle VMs Hours", "N/A", "N/A"],
-                    ["Resource Utilization", "N/A", "N/A"],
+                    ["Metric", "Value"],
+                    ["Allocated VMs Hours", "N/A"],
+                    ["Powered-on VMs Hours", "N/A"],
+                    ["Utilized Capacity Hours", "N/A"],
+                    ["Idle Capacity Hours", "N/A"],
+                    ["Capacity Utilization", "N/A"],
                 ]
         else:
             usage_data = [
-                ["Metric", "Value", "Status"],
-                ["Allocated VMs Hours", "1500", "Normal"],
-                ["Powered-on VMs Hours", "750", "Good"],
-                ["Utilized VMs Hours", "250", "Optimal"],
-                ["Idle VMs Hours", "500", "Normal"],
-                ["Resource Utilization", "65%", "Optimal"],
+                ["Metric", "Value"],
+                ["Allocated VMs Hours", "1500"],
+                ["Powered-on VMs Hours", "750"],
+                ["Utilized Capacity Hours", "250"],
+                ["Idle Capacity Hours", "500"],
+                ["Capacity Utilization", "65%"],
             ]
 
         # Convert table data to Paragraphs for word wrapping
@@ -234,7 +294,7 @@ def create_pool_pdf_report(org_id: str, resource_id: str, resource_type: str, te
             wrapped_row = [Paragraph(str(cell), normal_style) for cell in row]
             usage_data_wrapped.append(wrapped_row)
 
-        usage_table = Table(usage_data_wrapped, colWidths=[2.5 * inch, 2.5 * inch, 2.5 * inch])
+        usage_table = Table(usage_data_wrapped, colWidths=[3.5 * inch, 3.5 * inch])
         usage_table.setStyle(
             TableStyle(
                 [
@@ -291,6 +351,16 @@ def create_pool_pdf_report(org_id: str, resource_id: str, resource_type: str, te
                     # Get Utilized Capacity data
                     utilized_capacity_full = history.get("consumedSessions", [])
 
+                    # Handle MULTI_SESSION templates by converting sessions to VM-equivalent
+                    template = template_info.get("template", {})
+                    template_type = template.get("templateType", "")
+                    sessions_per_vm = 1
+                    if template_type == "MULTI_SESSION":
+                        sessions_per_vm = template.get("sessionsPerVm", 1)
+                        # Convert sessions to VM-equivalent capacity
+                        if sessions_per_vm > 0:
+                            utilized_capacity_full = [sessions / sessions_per_vm for sessions in utilized_capacity_full]
+
                     # Ensure all arrays have the same length
                     powered_on_vms_full = powered_on_vms_full[:len_history]
                     utilized_capacity_full = utilized_capacity_full[:len_history]
@@ -304,7 +374,7 @@ def create_pool_pdf_report(org_id: str, resource_id: str, resource_type: str, te
                     plt.fill_between(time_slots_full, provisioned_vms_full, color="blue", alpha=0.5, label="Allocated VMs")
                     plt.fill_between(time_slots_full, powered_on_vms_full, color="red", alpha=0.5, label="Powered-on VMs")
                     plt.fill_between(time_slots_full, utilized_capacity_full, color="green", alpha=0.5, label="Utilized Capacity")
-                    plt.title(f"VM Utilization Trends - Full View (Every {meta_data['timeslotMs']/(1000 * 60)} Minutes Sampling)")
+                    plt.title(f"VM Utilization Trends - Full View (Every {meta_data['timeslotMs'] / (1000 * 60)} Minutes Sampling)")
                     plt.xlabel("Time")
                     plt.ylabel("VM Count")
                     plt.grid(True)
@@ -330,54 +400,6 @@ def create_pool_pdf_report(org_id: str, resource_id: str, resource_type: str, te
                     temp_files.append(temp_file_full)
                     doc._temp_files = temp_files
 
-                    # --- Simplified View Chart (Daily Sampling) ---
-                    plt.figure(figsize=(10, 6))
-                    num_days = int(len_history / (24 * 2))
-                    time_slots_daily = [start_time + datetime.timedelta(hours=24 * i) for i in range(num_days)]
-                    provisioned_vms_daily_avg = [sum(history["provisionedVms"][i * 48 : (i + 1) * 48]) / 48 for i in range(num_days)]
-
-                    # Calculate daily averages for Powered-on VMs
-                    powered_on_vms_daily_avg = []
-                    for i in range(num_days):
-                        start_idx = i * 48
-                        end_idx = (i + 1) * 48
-                        daily_powered_on = []
-                        for j in range(start_idx, min(end_idx, len(powered_on_vms_full))):
-                            daily_powered_on.append(powered_on_vms_full[j])
-                        avg = sum(daily_powered_on) / len(daily_powered_on) if daily_powered_on else 0
-                        powered_on_vms_daily_avg.append(avg)
-
-                    # Calculate daily averages for Utilized Capacity
-                    utilized_capacity_daily_avg = [sum(utilized_capacity_full[i * 48 : (i + 1) * 48]) / 48 for i in range(num_days)]
-
-                    plt.fill_between(time_slots_daily, provisioned_vms_daily_avg, color="blue", alpha=0.5, label="Allocated VMs")
-                    plt.fill_between(time_slots_daily, powered_on_vms_daily_avg, color="red", alpha=0.5, label="Powered-on VMs")
-                    plt.fill_between(time_slots_daily, utilized_capacity_daily_avg, color="green", alpha=0.5, label="Utilized Capacity")
-                    plt.title("VM Utilization Trends - Simplified View (Daily Sampling)")
-                    plt.xlabel("Time")
-                    plt.ylabel("VM Count")
-                    plt.grid(True)
-                    # Adjust legend position and add padding
-                    plt.legend(bbox_to_anchor=(1.05, 1), loc="upper left", borderaxespad=0.0)
-                    plt.gca().xaxis.set_major_formatter(mdates.DateFormatter("%Y-%m-%d"))
-                    plt.gcf().autofmt_xdate()
-                    plt.xlim(start_time, start_time + datetime.timedelta(days=num_days))
-                    # Add more padding to prevent label overlapping
-                    plt.tight_layout(pad=3.0)
-                    buf_daily = io.BytesIO()
-                    plt.savefig(buf_daily, format="png", dpi=300, bbox_inches="tight")
-                    plt.close()
-                    buf_daily.seek(0)
-                    temp_file_daily = os.path.join(temp_dir, f"vm_utilization_daily_{int(time.time())}.png")
-                    with open(temp_file_daily, "wb") as f:
-                        f.write(buf_daily.getvalue())
-                    buf_daily.close()
-                    img_daily = Image(temp_file_daily, width=9 * inch, height=5 * inch)
-                    content.append(img_daily)
-                    temp_files = getattr(doc, "_temp_files", [])
-                    temp_files.append(temp_file_daily)
-                    doc._temp_files = temp_files
-
         # Part 2: Recommendations
         content.append(Paragraph("Part 2: Recommendation Actions", heading_style))
 
@@ -504,7 +526,7 @@ def create_org_pdf_report(org_details: dict, all_recommendations: list, filename
     usable_width = page_width - left_margin - right_margin
 
     content = []
-    content.append(Paragraph(f"Horizon Cloud Next-gen Advisor Report", title_style))
+    content.append(Paragraph("Horizon Cloud Next-gen Advisor Report", title_style))
     content.append(Paragraph(f"Organization: {org_name}", heading_style))
     content.append(Spacer(1, 20))
 
