@@ -21,9 +21,10 @@ from hcs_cli.service.app_management import manual_app
 
 
 @click.command()
+@cli.limit
 @cli.org_id
 def list(org: str, **kwargs):
-    """List manual apps"""
+    """List apps"""
     ret = manual_app.list(org_id=cli.get_org_id(org), **kwargs)
     recent.helper.default_list(ret, "app")
     return ret
