@@ -19,15 +19,13 @@ import os
 import re
 import shutil
 import subprocess
-import tempfile
 import time
 from collections import OrderedDict, defaultdict
 from pathlib import Path
 
 import click
 import hcs_core.sglib.cli_options as cli
-import yaml
-from dotenv import find_dotenv, load_dotenv
+from dotenv import load_dotenv
 from hcs_core.ctxp import context, profile
 from hcs_core.ctxp.util import error_details
 from InquirerPy import inquirer
@@ -43,22 +41,10 @@ from hcs_cli.cmds.dev.fs.common.log import fail as fail
 from hcs_cli.cmds.dev.fs.common.step_util import step as step
 from hcs_cli.cmds.dev.fs.k8s_util import kubectl
 from hcs_cli.service import auth, org_service
-from hcs_cli.support.exec_util import exec
+from hcs_cli.service.admin.uag import list as list_uags
+from hcs_cli.support.exec_util import exec, run_cli
 from hcs_cli.support.template_util import with_template_file
 
-
-def check_ssh_access():
-    print("🔐 Checking SSH access to GitHub...")
-    result = subprocess.run(["ssh", "-T", "git@github.com"], capture_output=True, text=True)
-    cmd = "ssh -T git@github.com"
-    exec(cmd, log_error=False, raise_on_error=False, inherit_output=False).stdout
-    if result.returncode != 1 and result.returncode != 0:
-        fail(
-            "SSH access to GitHub failed. Please follow instructions at https://docs.github.com/en/authentication/connecting-to-github-with-ssh before proceeding."
-        )
-    log.good("SSH access confirmed.")
-
-
 _delete_temp_files = False
 
 
@@ -78,11 +64,12 @@ _delete_temp_files = False
 def init(interactive: bool, step: str, jenkins: str, fs_name: str, delete_temp_files: bool, **kwargs):
     """Initialize feature stack with common settings and infrastructure."""
 
-    if not profile.current().namespace and not fs_name:
-        fail("Usage: hcs dev fs init <YOUR_FEATURE_STACK_ID>")
-
     if not fs_name:
-        fs_name = profile.current().namespace
+        fs_name = profile.name()
+
+    if fs_name == "default":
+        # default is not valid. Should be FS short id.
+        fail("Usage: hcs dev fs init <YOUR_FEATURE_STACK_ID>")
 
     global _delete_temp_files
     _delete_temp_files = delete_temp_files
@@ -99,27 +86,26 @@ def init(interactive: bool, step: str, jenkins: str, fs_name: str, delete_temp_f
         _get_client_credential_from_k8s_and_update_profile()
         _validate_fs_auth()
         _common_init()
+        _create_idp()
         _create_infra_akka()
         _create_infra_lcm_zerocloud()
-        _create_infra_azure()
+        _create_infra_azure(fs_name)
         _create_infra_azsim()
-    _map_fqdn_to_lb(fs_name)
     log.good("Done")
 
 
 @step
 def _common_init():
-    _patch_mqtt_alias()
-    _update_mqtt()
-    _show_mqtt_info()
-    _test_mqtt()
     _reg_datacenter()
     _create_org_details()
     _create_org_location_mapping()
     _create_license_info()
+    _patch_mqtt_alias()
+    _update_mqtt()
+    _show_mqtt_info()
+    _test_mqtt()
     _restart_services()
     _wait_for_services_restart()
-    _create_idp()
     _touch_fs_to_avoid_recycle()
 
 
@@ -139,7 +125,6 @@ def _prepare_profile(fs_name: str):
         profile_data["csp"]["apiToken"] = api_token
         profile_data["csp"]["clientId"] = hcs_client_id
         profile_data["csp"]["clientSecret"] = hcs_client_secret
-        profile_data["namespace"] = fs_name
         profile.create(fs_name, profile_data, overwrite=False, auto_use=True)
     else:
         if profile.name() != fs_name:
@@ -148,12 +133,6 @@ def _prepare_profile(fs_name: str):
         profile_data = profile.current()
         _validate_fs_url(profile_data.hcs.url)
         updated = False
-        if profile_data["namespace"] != fs_name:
-            log.warn(
-                f"Current profile namespace ({profile_data['namespace']}) does not match provided namespace ({fs_name}). Updating profile to use the specified namespace."
-            )
-            profile_data["namespace"] = fs_name
-            updated = True
         if env_org_id and profile_data.csp.orgId != env_org_id:
             log.warn(
                 f"Current profile orgId ({profile_data.csp.orgId}) does not match provided orgId. Updating profile to use the specified orgId {env_org_id}."
@@ -289,13 +268,13 @@ def _retrieve_config_from_nightly_repo():
 
 
 @step
-def _create_infra_azure():
+def _create_infra_azure(fs_name):
     # use the following command to inspect the resolved file
     #   hcs plan resolve
     # or examine the finally resolved input after deployment:
     #   hcs plan input
     azure_plan_path = _resolve_bundled_file_path("provided_files/azure.plan.yml")
-    ret = _hcs("plan apply -f " + azure_plan_path, raise_on_error=False)
+    ret = run_cli("hcs plan apply -f " + azure_plan_path, raise_on_error=False)
     if ret.returncode != 0:
         log.warn("Failed to apply Azure plan. Please check the output for details.")
         return
@@ -303,7 +282,7 @@ def _create_infra_azure():
     # To get the output, use the following command:
     #   hcs plan output -d
     # or programatically
-    details = _hcs("plan output --details", output_json=True)
+    details = run_cli("hcs plan output --details", output_json=True)
 
     # store in context
     context.set("infra", details)
@@ -312,14 +291,14 @@ def _create_infra_azure():
     # infra = context.get("infra")
     # print(json.dumps(infra['mySite'], indent=4))
     # print(json.dumps(infra['myProvider'], indent=4))
-
+    _map_fqdn_to_lb(fs_name)
     log.good("Azure infrastructure set up.")
 
 
 @step
 def _create_infra_azsim():
     azusim_plan_path = _resolve_bundled_file_path("provided_files/azsim.plan.yml")
-    ret = _hcs("plan apply -f " + azusim_plan_path, raise_on_error=False)
+    ret = run_cli("hcs plan apply -f " + azusim_plan_path, raise_on_error=False)
     if ret.returncode == 0:
         log.good("Azure simulator infrastructure set up.")
     else:
@@ -329,7 +308,7 @@ def _create_infra_azsim():
 @step
 def _create_infra_akka():
     infra_plan_path = _resolve_bundled_file_path("provided_files/akka.plan.yml")
-    ret = _hcs("plan apply -f " + infra_plan_path, raise_on_error=False)
+    ret = run_cli("hcs plan apply -f " + infra_plan_path, raise_on_error=False)
     if ret.returncode == 0:
         log.good("Akka infrastructure set up.")
     else:
@@ -338,9 +317,9 @@ def _create_infra_akka():
 
 @step
 def _create_infra_lcm_zerocloud():
-    _hcs("lcm template create -p zero-floating", output_json=True)
-    _hcs("lcm template create -p zero-dedicated", output_json=True)
-    _hcs("lcm template create -p zero-multisession", output_json=True)
+    run_cli("hcs lcm template create -p zero-floating", output_json=True)
+    run_cli("hcs lcm template create -p zero-dedicated", output_json=True)
+    run_cli("hcs lcm template create -p zero-multisession", output_json=True)
     log.good("LCM Zerocloud template.")
 
 
@@ -500,10 +479,12 @@ def _write_env_file(data, props, env_file):
         config_block = f"""HCS_CLIENT_ID={props['csp.service.app.client_id']}
         HCS_CLIENT_SECRET={props['csp.service.app.client_secret']}
         IDP_TENANT_DOMAIN=test-sanity-domain
-        UAG_FQDN=abc.xyz
+        UAG_FQDN=myuag.fqdn
         DESKTOP_SUBNET_CIDR=10.76.0.0/16
         DMZ_SUBNET_CIDR=10.77.0.0/24
         MANAGEMENT_SUBNET_CIDR=10.77.3.0/24
+        TENANT_SUBNET=desktop-76
+        TENANT_SUBNET_CIDR=10.76.0.0/16
         DESKTOP_RESOURCE_GROUP=horizonv2-sg-dev
         INFRA_RESOURCE_GROUP=horizonv2-sg-dev
         DESKTOP_VNET=horizonv2-sg-dev-vnet
@@ -522,6 +503,7 @@ def _write_env_file(data, props, env_file):
         IMAGE_PASSWORD={ad_password}
         VM_USER_NAME={ad_username}
         VM_PASSWORD={ad_password}
+        DEPLOYMENT_ID=az-1
         """
         f.write(config_block)
 
@@ -562,11 +544,21 @@ def _organize_env_file(env_file):
             ("Resource and Network Configuration", ["DESKTOP_RESOURCE_GROUP", "INFRA_RESOURCE_GROUP", "DESKTOP_VNET", "INFRA_VNET"]),
             (
                 "Subnet",
-                ["DMZ_SUBNET", "DMZ_SUBNET_CIDR", "DESKTOP_SUBNET", "DESKTOP_SUBNET_CIDR", "MANAGEMENT_SUBNET", "MANAGEMENT_SUBNET_CIDR"],
+                [
+                    "DMZ_SUBNET",
+                    "DMZ_SUBNET_CIDR",
+                    "DESKTOP_SUBNET",
+                    "DESKTOP_SUBNET_CIDR",
+                    "MANAGEMENT_SUBNET",
+                    "MANAGEMENT_SUBNET_CIDR",
+                    "TENANT_SUBNET",
+                    "TENANT_SUBNET_CIDR",
+                ],
             ),
             ("Resource Credentials", ["IMAGE_USER_NAME", "IMAGE_PASSWORD", "VM_USER_NAME", "VM_PASSWORD"]),
             ("UAG", ["UAG_FQDN"]),
             ("Entitlement", ["ENTITLEMENT_USER_1", "ENTITLEMENT_USER_2"]),
+            ("Deployment ID", ["DEPLOYMENT_ID"]),
         ]
     )
 
@@ -610,7 +602,7 @@ def _cleanup_repo(clone_dir):
 
 @step
 def _touch_fs_to_avoid_recycle():
-    namespace = profile.current().namespace
+    namespace = profile.name()
     ns_json = kubectl(f"get namespace {namespace} -ojson", get_json=True)
     metadata = ns_json.get("metadata", {})
     # Update annotations
@@ -649,12 +641,12 @@ def _run_single_step(name):
 
 @step
 def _prepare_k8s_config(jenkins: str = None):
-    fs_name = profile.current().namespace
+    fs_name = profile.name()
     try:
         if not k8s_util.validate_kubectl_config(fs_name, raise_on_error=False):
             feature_stack_service = jenkins if jenkins else os.getenv("FEATURE_STACK_SERVICE")
             if feature_stack_service:
-                print(f"kubectl config validation failed.")
+                print("kubectl config validation failed.")
                 print(f"Retrieving feature stack kubeconfig from Jenkins pipeline: {feature_stack_service}")
                 jenkins_util.download_kubeconfig(feature_stack_service)
                 k8s_util.validate_kubectl_config(fs_name, raise_on_error=True)
@@ -663,8 +655,8 @@ def _prepare_k8s_config(jenkins: str = None):
         fail(
             "Feature stack kubectl config is not set.\n"
             "Recovery options:\n"
-            "  1. Provide FEATURE_STACK_SERVICE=<service-name> in .env file, to download kubeconfig from Jenkins feature stack pipeline.\n"
-            f"  2. Or download and copy feature stack kubeconfig to ~/.kube/config\n"
+            "  1. Download and copy feature stack kubeconfig to ~/.kube/_fs_config\n"
+            "  2. Or specify service name that triggered FS, using 'hcs dev fs <fs-name> --jenkins <service-name>', to download kubeconfig from Jenkins feature stack pipeline.\n"
         )
 
 
@@ -674,18 +666,6 @@ def _resolve_bundled_file_path(relative_path: str):
     return os.path.join(base_path, relative_path)
 
 
-def _hcs(cmd: str, output_json=False, raise_on_error=True):
-    cmd = f"hcs {cmd}"
-    if output_json:
-        output = exec(cmd, log_error=True, raise_on_error=raise_on_error, inherit_output=False).stdout
-        try:
-            return json.loads(output)
-        except json.JSONDecodeError as e:
-            fail(f"Failed to parse JSON output from command '{cmd}': {e}\nOutput: {output}")
-    else:
-        return exec(cmd, log_error=False, raise_on_error=raise_on_error, inherit_output=True)
-
-
 @step
 def _patch_mqtt_alias():
     with_template_file(
@@ -700,7 +680,10 @@ def _patch_mqtt_alias():
 
 @step
 def _show_mqtt_info():
-    ret = kubectl(f"exec -t mqtt-server-0 -- vmq-admin session show", ignore_error=True)
+    ret = kubectl("exec -t mqtt-server-0 -- vmq-admin session show", ignore_error=True)
+    if not ret:
+        log.warn("MQTT session info not available.")
+        return
     print(ret.stdout)
     if ret.stderr:
         print("Error retrieving MQTT session info:", ret.stderr)
@@ -708,9 +691,10 @@ def _show_mqtt_info():
 
 @step
 def _update_mqtt():
+    namespace = profile.name()
     with_template_file(
         "provided_files/mqtt-server-external.yaml",
-        substitutions={r"(namespace:\s*)\S+": rf"\1{profile.current().namespace}"},
+        substitutions={r"(namespace:\s*)\S+": rf"\1{namespace}"},
         fn=lambda temp_file_path: kubectl(f"apply -f {temp_file_path}"),
         base_path=__file__,
         delete_after=_delete_temp_files,
@@ -721,7 +705,7 @@ def _update_mqtt():
     with_template_file(
         "provided_files/mqtt-secret.yaml",
         substitutions={
-            r"(namespace:\s*)\S+": rf"\1{profile.current().namespace}",
+            r"(namespace:\s*)\S+": rf"\1{namespace}",
             r'(mqtt\.server-host:\s*)".*?"': rf'\1"{ip_address}"',
         },
         fn=lambda temp_file_path: kubectl(f"apply -f {temp_file_path}"),
@@ -749,7 +733,7 @@ def _test_mqtt():
 def _retrieve_mqtt_server_ip_address(service_name, timeout=300, interval=5):
     start = time.time()
     while time.time() - start < timeout:
-        result = kubectl(f"get service mqtt-server-external")
+        result = kubectl("get service mqtt-server-external")
         output = result.stdout.strip().splitlines()
 
         if len(output) >= 2:
@@ -964,7 +948,15 @@ def _reg_datacenter():
         ],
     }
     try:
-        ret = org_service.datacenter.create(payload1)
+        # ret = org_service.datacenter.create(payload1)
+
+        from hcs_core.sglib.hcs_client import hcs_client
+
+        profile_data = profile.current()
+        url = profile_data.hcs.url
+        custom_auth = profile_data.csp
+        custom_client = hcs_client(url=url, custom_auth=custom_auth)
+        ret = custom_client.post("/org-service/v1/datacenters", payload1)
         print(ret)
         log.good("Datacenter registered.")
     except Exception as e:
@@ -976,8 +968,9 @@ def _reg_datacenter():
 
 @step
 def _create_org_details():
+    namespace = profile.name()
     payload2 = {
-        "customerName": f"{profile.current().namespace}-dev",
+        "customerName": f"{namespace}-dev",
         "customerType": "INTERNAL",
         "orgId": profile.current().csp.orgId,
         "wsOneOrgId": "pseudo-ws1-org-id",
@@ -1033,10 +1026,10 @@ def _create_idp():
 
 @step
 def _restart_services():
-    kubectl("rollout restart deployment portal-deployment")
-    kubectl("rollout restart statefulset vmhub-statefulset")
-    kubectl("rollout restart statefulset connection-service-statefulset")
-    kubectl("rollout restart statefulset clouddriver-statefulset")
+    kubectl("rollout restart deployment portal-deployment", ignore_error=True)
+    kubectl("rollout restart statefulset vmhub-statefulset", ignore_error=True)
+    kubectl("rollout restart statefulset connection-service-statefulset", ignore_error=True)
+    kubectl("rollout restart statefulset clouddriver-statefulset", ignore_error=True)
 
     # TODO: not sure why restart of this deployment failed
     # kubectl("rollout restart deployment infra-vsphere-twin-deployment")
@@ -1051,7 +1044,26 @@ def _wait_for_services_restart():
     time.sleep(60)
 
 
+def check_ssh_access():
+    print("🔐 Checking SSH access to GitHub...")
+    result = subprocess.run(["ssh", "-T", "git@github.com"], capture_output=True, text=True)
+    cmd = "ssh -T git@github.com"
+    exec(cmd, log_error=False, raise_on_error=False, inherit_output=False).stdout
+    if result.returncode != 1 and result.returncode != 0:
+        fail(
+            "SSH access to GitHub failed. Please follow instructions at https://docs.github.com/en/authentication/connecting-to-github-with-ssh before proceeding."
+        )
+    log.good("SSH access confirmed.")
+
+
 def _map_fqdn_to_lb(fs_name):
-    print("The next step requires adding FQDN mapping. Run the following command in another window:")
-    print(f'echo "<YOUR_UAG_LB_IP_ADDRESS> {os.getenv("UAG_FQDN")}" | sudo tee -a /etc/hosts')
-    log.info(f"After that, you can view your desktops at https://{fs_name}.fs.devframe.cp.horizon.omnissa.com/appblast/endpoint/appblast")
+    orgId = profile.current().csp.orgId
+    deployment_id = os.getenv("DEPLOYMENT_ID")
+    for uag in list_uags(orgId):
+        if uag.get("name") == deployment_id and uag.get("orgId") == orgId:
+            print("The next step requires adding FQDN mapping. Run the following command in another window:")
+            print(f'echo "{uag["loadBalancer"]["ipAddress"]} {os.getenv("UAG_FQDN")}" | sudo tee -a /etc/hosts')
+            log.info(
+                f"After that, you can view your desktops at https://{fs_name}.fs.devframe.cp.horizon.omnissa.com/appblast/endpoint/appblast"
+            )
+            break
