@@ -17,7 +17,7 @@ import click
 import hcs_core.sglib.cli_options as cli
 from hcs_core.ctxp import recent
 
-from hcs_cli.service import admin
+from hcs_cli.service import edge
 
 
 @click.command()
@@ -27,7 +27,7 @@ def connection_string(id: str, org: str):
     """Get edge connection string"""
     org_id = cli.get_org_id(org)
     id = recent.require("edge", id)
-    ret = admin.edge.get_connection_string(id, org_id=org_id)
+    ret = edge.get_connection_string(id, org_id=org_id)
     if ret:
         return ret
     return "", 1
