@@ -17,7 +17,7 @@ import click
 import hcs_core.sglib.cli_options as cli
 from hcs_core.ctxp import recent
 
-from hcs_cli.service import admin
+from hcs_cli.service import edge
 
 
 @click.command()
@@ -27,7 +27,7 @@ def get(id: str, org: str):
     """Get edge by ID"""
 
     id = recent.require("edge", id)
-    ret = admin.edge.get(id, org_id=cli.get_org_id(org))
+    ret = edge.get(id, org_id=cli.get_org_id(org))
     if ret:
         return ret
     return "", 1
