@@ -17,7 +17,7 @@ import click
 import hcs_core.sglib.cli_options as cli
 from hcs_core.ctxp import recent
 
-from hcs_cli.service import admin
+from hcs_cli.service import edge
 
 
 @click.command()
@@ -26,7 +26,7 @@ from hcs_cli.service import admin
 def list(org: str, **kwargs):
     """List edges"""
     org_id = cli.get_org_id(org)
-    ret = admin.edge.list(org_id, **kwargs)
+    ret = edge.list(org_id, **kwargs)
 
     recent.helper.default_list(ret, "edge")
 
