@@ -1,14 +1,6 @@
-import json
-import re
-import sys
-
 import click
-import yumako
 from hcs_core.sglib import cli_options as cli
 
-from hcs_cli.service import VM, hoc
-from hcs_cli.support import predefined_payload
-
 
 @click.command()
 @cli.org_id
