@@ -18,16 +18,18 @@ import hcs_core.sglib.cli_options as cli
 from hcs_core.ctxp import recent
 
 from hcs_cli.service import inventory
+from hcs_cli.support.vm_table import format_vm_table
 
 
 @click.command()
 @cli.org_id
 @click.argument("template_id", type=str, required=False)
+@cli.formatter(format_vm_table)
 def list(template_id: str, org: str):
     """List template VMs"""
     template_id = recent.require("template", template_id)
     ret = inventory.list(template_id, cli.get_org_id(org))
     recent.helper.default_list(ret, "vm")
     if not ret:
-        return "", 1
+        return ""
     return ret
