@@ -24,4 +24,12 @@ from hcs_cli.service.lcm import provider
 def delete(id: str):
     """Delete provider by ID"""
     id = recent.require("provider", id)
-    return provider.delete(id)
+    ret = provider.delete(id)
+
+    # trick
+    if ret is True:  # found
+        return
+    if ret is None:  # not found
+        return
+
+    return ret, 1
