@@ -35,7 +35,7 @@ def delete(id: str, org: str, force: bool, confirm: bool, wait: str):
         return
 
     if not confirm:
-        click.confirm(f"Delete template {t['name']} ({id})?", abort=True)
+        click.confirm(f"Delete template {t['name']} ({id}/{t['templateType']})?", abort=True)
 
     ret = template.delete(id, org_id, force)
 
