@@ -24,7 +24,8 @@ from hcs_cli.support.param_util import parse_vm_path
 @click.argument("vm_path", type=str, required=False)
 @cli.org_id
 @cli.confirm
-def delete(vm_path: str, org: str, confirm: bool, **kwargs):
+@cli.wait
+def delete(vm_path: str, org: str, confirm: bool, wait: str, **kwargs):
     """Delete VM"""
     template_id, vm_id = parse_vm_path(vm_path)
     org_id = cli.get_org_id(org)
@@ -37,3 +38,8 @@ def delete(vm_path: str, org: str, confirm: bool, **kwargs):
         click.confirm(f"Delete VM {template_id}/{vm_id}?", abort=True)
 
     vm.delete(template_id, vm_id, org_id, **kwargs)
+
+    if wait == "0":
+        return
+
+    return vm.wait_for_deleted(template_id, vm_id, org_id, wait)
