@@ -13,11 +13,8 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
-import sys
-
 import click
 import hcs_core.plan as plan
-from hcs_core.ctxp.util import error_details
 
 import hcs_cli.support.plan_util as plan_util
 
