@@ -32,12 +32,10 @@ def get(label: str, id: str, org: str, **kwargs):
 
     if label:
         ret = admin.provider.get(label, id, org_id=org_id, **kwargs)
-    else:
-        for label in provider_labels:
-            ret = admin.provider.list(org_id=cli.get_org_id(org), label=label, **kwargs)
-            if ret:
-                ret = ret[0]
-                break
-    if ret:
         return ret
+
+    for label in provider_labels:
+        ret = admin.provider.get(label, id, org_id=org_id)
+        if ret:
+            return ret
     return "", 1
