@@ -17,7 +17,7 @@ import click
 import hcs_core.sglib.cli_options as cli
 from hcs_core.ctxp import recent
 
-from hcs_cli.service import portal
+from hcs_cli.service import site
 
 
 @click.command()
@@ -28,7 +28,7 @@ def create(name: str, description: str, org: str):
     """Create a site."""
     org_id = cli.get_org_id(org)
     payload = {"name": name, "description": description, "orgId": org_id}
-    ret = portal.site.create(payload)
+    ret = site.create(payload)
     if ret:
         recent.set("site", ret["id"])
         return ret
