@@ -17,7 +17,7 @@ import click
 import hcs_core.sglib.cli_options as cli
 from hcs_core.ctxp import recent
 
-from hcs_cli.service import portal
+from hcs_cli.service import site
 
 
 @click.command()
@@ -29,12 +29,12 @@ def delete(id: str, org: str, confirm: bool):
     org_id = cli.get_org_id(org)
     id = recent.require("site", id)
 
-    ret = portal.site.get(id, org_id)
+    ret = site.get(id, org_id)
     if not ret:
         return
 
     if not confirm:
         click.confirm(f"Delete site {ret['name']} ({id})?", abort=True)
 
-    ret = portal.site.delete(id, org_id)
+    ret = site.delete(id, org_id)
     return ret
