@@ -17,7 +17,7 @@ import click
 import hcs_core.sglib.cli_options as cli
 from hcs_core.ctxp import recent
 
-from hcs_cli.service import portal
+from hcs_cli.service import site
 
 
 @click.command()
@@ -27,7 +27,7 @@ def get(id: str, org: str):
     """Get site."""
     org_id = cli.get_org_id(org)
     id = recent.require("site", id)
-    ret = portal.site.get(id, org_id)
+    ret = site.get(id, org_id)
     if ret:
         return ret
     return "", 1
