@@ -17,7 +17,7 @@ import click
 import hcs_core.sglib.cli_options as cli
 from hcs_core.ctxp import recent
 
-from hcs_cli.service import portal
+from hcs_cli.service import site
 
 
 @click.command()
@@ -29,4 +29,4 @@ def set_edge(site_id: str, edge: str, org: str, **kwargs):
     site_id = recent.require("site", site_id)
     edge_id = recent.require("edge", edge)
     org_id = cli.get_org_id(org)
-    return portal.site.set_edge(site_id, org_id, edge_id, **kwargs)
+    return site.set_edge(site_id, org_id, edge_id, **kwargs)
