@@ -13,10 +13,6 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
-import traceback
-from datetime import datetime
-from time import sleep
-
 import click
 import hcs_core.ctxp.cli_options as cli
 from hcs_core.ctxp.extension import ensure_extension
