@@ -16,7 +16,7 @@ limitations under the License.
 import click
 from hcs_core.util import pki_util
 
-from hcs_cli.service.vmhub import otp as otp_service
+from hcs_cli.service.vmhub import credentials as otp_service
 
 
 @click.command()
@@ -37,5 +37,7 @@ def redeem(region: str, resource_name: str, otp: str, ca_label: str):
     csr_pem, private_key_pem = pki_util.generate_CSR(resource_name)
 
     ret = otp_service.redeem(resource_name, otp, csr_pem, ca_label)
+    if not ret:
+        return "Failed to redeem OTP", 1
     ret.private_key = private_key_pem
     return ret
