@@ -16,7 +16,7 @@ limitations under the License.
 import click
 import hcs_core.sglib.cli_options as cli
 
-from hcs_cli.service.vmhub import otp
+from hcs_cli.service.vmhub import credentials
 
 
 @click.command()
@@ -32,5 +32,5 @@ from hcs_cli.service.vmhub import otp
 def request(org: str, region: str, resource_name: str):
     """Request an one-time password for a specific resource"""
     org_id = cli.get_org_id(org)
-    otp.use_region(region)
-    return otp.request(org_id, resource_name)
+    credentials.use_region(region)
+    return credentials.request(org_id, resource_name)
