@@ -24,9 +24,8 @@ import hcs_core.sglib.cli_options as cli
 import httpx
 
 from hcs_cli.service import admin, ims, inventory, org_service, pki, vmm
-from hcs_cli.service.pki import certificate
 
-MIN_SUPPORTED_AGENT_VERSION = "24.4.0"
+MIN_SUPPORTED_AGENT_VERSION = "24.2.0"
 global common_dict
 common_dict = dict()
 
@@ -51,7 +50,7 @@ def stats(org: str, edge_ids: str, run_id: str, verbose: bool):
     if target_org_id.upper() == "ALL" and edge_ids:
         return "edge_ids can't be specified when --org all is specified", 1
 
-    logger.info(f"Started gather edge migration stats:")
+    logger.info("Started gather edge migration stats:")
     logger.info("\n")
     logger.info(f"default timeout for API calls: {os.environ.get('HCS_TIMEOUT', 30)} seconds")
 
@@ -60,7 +59,7 @@ def stats(org: str, edge_ids: str, run_id: str, verbose: bool):
     else:
         common_dict["RUN_ID"] = str(datetime.now().strftime("%m%d%Y%H%M%S"))
 
-    logger.info(f"Command Inputs:")
+    logger.info("Command Inputs:")
     logger.info(f"Org = {target_org_id}")
     logger.info(f"EdgeIds = {edge_ids}")
     logger.info(f"verbose = {verbose}")
@@ -282,13 +281,13 @@ def get_all_template_images_and_vms_stats(org: dict, edge: dict, edge_stats: dic
     for template_stats in all_template_stats:
         if (
             "is_using_custom_vm_image" in template_stats.keys()
-            and template_stats.get("is_using_custom_vm_image") == False
+            and template_stats.get("is_using_custom_vm_image") is False
             and "is_vm_image_on_valid_agent_version" in template_stats.keys()
-            and template_stats.get("is_vm_image_on_valid_agent_version") == False
-        ) or ("all_vms_on_valid_agent_version" in template_stats.keys() and template_stats.get("all_vms_on_valid_agent_version") == False):
+            and template_stats.get("is_vm_image_on_valid_agent_version") is False
+        ) or ("all_vms_on_valid_agent_version" in template_stats.keys() and template_stats.get("all_vms_on_valid_agent_version") is False):
             edge_migration_eligible = False
 
-        if "are_all_vms_migrated" in template_stats.keys() and template_stats.get("are_all_vms_migrated") == False:
+        if "are_all_vms_migrated" in template_stats.keys() and template_stats.get("are_all_vms_migrated") is False:
             are_all_templates_vms_migrated = False
 
     logger.info(
@@ -328,7 +327,7 @@ def get_edge_stats(edge: dict, verbose: bool):
     edge_mqtt_url = data_util.deep_get_attr(edge, "fqdn", raise_on_not_found=False)
     edge_migrated = False
     if (
-        (edge_fqdn_auto_generated == False or (edge_fqdn_auto_generated == True and edge_mqtt_url and ".omnissa." in edge_mqtt_url))
+        (edge_fqdn_auto_generated is False or (edge_fqdn_auto_generated is True and edge_mqtt_url and ".omnissa." in edge_mqtt_url))
         and edge_ca_label_on_pki
         and edge_ca_label_on_pki == "omnissa"
         and ((not regional_mqtt_url) or (regional_mqtt_url and ".omnissa." in regional_mqtt_url))
@@ -361,7 +360,7 @@ def get_template_vms_stats(target_org_id: str, edge_id: str, template: dict, tem
                 and vm.get("regionalMqttEndpoint") is not None
                 and ".omnissa." in vm.get("regionalMqttEndpoint")
                 and (
-                    ("edge_fqdn_auto_generated" in template_stats and template_stats["edge_fqdn_auto_generated"] == False)
+                    ("edge_fqdn_auto_generated" in template_stats and template_stats["edge_fqdn_auto_generated"] is False)
                     or (vm.get("edgeMqttEndpoint") is not None and ".omnissa." in vm.get("edgeMqttEndpoint"))
                 )
             ):
@@ -392,7 +391,7 @@ def get_template_vms_stats(target_org_id: str, edge_id: str, template: dict, tem
     template_stats["total_vms"] = vm_count
 
 
-###########   SUPPORTING FUNCTIONS    #########################################################
+# SUPPORTING FUNCTIONS #########################################################
 
 
 def is_valid_agent_version(agent_version: str):
