@@ -124,7 +124,7 @@ def process_command_input(
     skip_active_session_vms: bool,
     verbose: bool,
 ):
-    logger.info(f"Starting RootCA migration:")
+    logger.info("Starting RootCA migration:")
     logger.info(f"default timeout for API calls: {os.environ.get('HCS_TIMEOUT', 30)} seconds")
     if batch_size and int(batch_size) > 0:
         common_dict["BATCH_SIZE"] = int(batch_size)
@@ -155,7 +155,7 @@ def process_command_input(
     logger.info(f"template_id: {template_id}")
     logger.info(f"vm_ids: {vm_ids}")
     logger.info(f"batch_size: {common_dict['BATCH_SIZE']}")
-    logger.info(f"failure_threshold: {common_dict['FAILURE_THRESHOLD'] }")
+    logger.info(f"failure_threshold: {common_dict['FAILURE_THRESHOLD']}")
     logger.info(f"poweredon_vms_only: {poweredon_vms_only}")
     logger.info(f"skip_active_session_vms: {skip_active_session_vms}")
     logger.info(f"verbose: {verbose}")
@@ -165,7 +165,7 @@ def process_command_input(
         migrate_edges(target_org_id, edge_ids, poweredon_vms_only, skip_active_session_vms, verbose)
     else:
         migrate_template_vms(target_org_id, template_id, vm_ids, poweredon_vms_only, skip_active_session_vms, verbose)
-    logger.info(f"Ended RootCA migration")
+    logger.info("Ended RootCA migration")
 
 
 def migrate_edges(target_org_id: str, edge_ids: str, poweredon_vms_only: bool, skip_active_session_vms: bool, verbose: bool):
@@ -175,7 +175,7 @@ def migrate_edges(target_org_id: str, edge_ids: str, poweredon_vms_only: bool, s
         logger.error(f"Invalid org id {target_org_id}")
         return
     if not edge_ids:
-        logger.error(f"edge_ids is not specified")
+        logger.error("edge_ids is not specified")
         return
     # edges = admin.edge.items(org_id=target_org_id, search="id $in " + edge_ids)
     edges = admin.edge.list(target_org_id, search="id $in " + edge_ids, size=100)
@@ -201,7 +201,7 @@ def migrate_template_vms(
     skip_active_session_vms: bool,
     verbose: bool,
 ):
-    logger.info(f"\n\n")
+    logger.info("\n\n")
     logger.info(f"Stated RootCA Migration on org_id: {target_org_id}, template_id: {template_id}")
     # declare all global variables
     global template_key_dict
@@ -409,7 +409,7 @@ def send_hoc_event_skipped_vms(
 
 
 def process_file(file: str, verbose: bool):
-    logger.info(f"Starting RootCA migration:")
+    logger.info("Starting RootCA migration:")
     logger.info(f"input file {file} specified. file input takes the precedence. processing the file now")
     logger.info(f"default timeout for API calls: {os.environ.get('HCS_TIMEOUT', 30)} seconds")
     if not os.path.isfile(file):
@@ -456,7 +456,7 @@ def process_file(file: str, verbose: bool):
     logger.info("\n")
     logger.info("Rootca VMs Migration - File Input:")
     logger.info(f"batch_size: {common_dict['BATCH_SIZE']}")
-    logger.info(f"failure_threshold: {common_dict['FAILURE_THRESHOLD'] }")
+    logger.info(f"failure_threshold: {common_dict['FAILURE_THRESHOLD']}")
     logger.info(f"poweredon_vms_only: {poweredon_vms_only}")
     logger.info(f"skip_active_session_vms: {skip_active_session_vms}")
     logger.info(f"verbose: {verbose}")
@@ -484,7 +484,7 @@ def process_file(file: str, verbose: bool):
             logger.warn(f"migrate_edges:{counter}: edges are not specified for org {target_org_id}. skipped migration for this org")
             continue
         migrate_edges(target_org_id, edge_ids, poweredon_vms_only, skip_active_session_vms, verbose)
-    logger.info(f"Ended RootCA migration")
+    logger.info("Ended RootCA migration")
 
 
 def get_template_and_edge_details(template: dict, org_id: str, verbose: bool):
@@ -544,7 +544,7 @@ def power_policy_on_template(template: dict, enable: bool, verbose: bool):
     try:
         data_util.deep_get_attr(template, "powerPolicy", raise_on_not_found=True)
         enabled = data_util.deep_get_attr(template, "powerPolicy.enabled", raise_on_not_found=True)
-        if enabled != None and enabled == False:
+        if enabled is not None and enabled is False:
             logger.info(f"powerPolicy already disabled on template {template_id}")
             return False
     except:
@@ -695,7 +695,7 @@ def perform_migration(template_key_dict: dict, vms: dict, target_org_id: str, te
             and template_key_dict[REGIONAL_MQTT_URL] in vm.get("regionalMqttEndpoint")
             and ".omnissa.com" in vm.get("regionalMqttEndpoint")
             and (
-                (EDGE_FQDN_AUTO_GENERATED in template_key_dict and template_key_dict.get(EDGE_FQDN_AUTO_GENERATED) == False)
+                (EDGE_FQDN_AUTO_GENERATED in template_key_dict and template_key_dict.get(EDGE_FQDN_AUTO_GENERATED) is False)
                 or (
                     vm.get("edgeMqttEndpoint") is not None
                     and template_key_dict[EDGE_MQTT_URL] in vm.get("edgeMqttEndpoint")
@@ -934,7 +934,7 @@ def perform_migration(template_key_dict: dict, vms: dict, target_org_id: str, te
 def log_vm_info(target_org_id: str, template_id: str, vm_id: str):
     vm = inventory.get(template_id, vm_id, target_org_id)
     logger.info(
-        f"vm %s - powerState: %s, haiAgentVersion: %s, agentStatus: %s, lifecycleStatus: %s, activeSessions: %s, regionalMqttEndpoint: %s, edgeMqttEndpoint: %s, agentCertIssuedByCALabel: %s",
+        "vm %s - powerState: %s, haiAgentVersion: %s, agentStatus: %s, lifecycleStatus: %s, activeSessions: %s, regionalMqttEndpoint: %s, edgeMqttEndpoint: %s, agentCertIssuedByCALabel: %s",
         vm["id"],
         vm.get("powerState"),
         vm.get("haiAgentVersion"),
