@@ -27,7 +27,6 @@ import hcs_core.sglib.cli_options as cli
 import httpx
 
 from hcs_cli.service import admin, org_service, pki, vmm
-from hcs_cli.service.pki import certificate
 
 # Create a logger
 logger = logging.getLogger("migrate_edge")
@@ -74,10 +73,10 @@ def migrate(org: str, edge_ids: str, ca_label: str, file: str, run_id: str, verb
     logger.info(f"verbose = {verbose}")
     logger.info(f"run_id = {common_dict['RUN_ID']}")
 
-    logger.info(f"Starting one-time edge migration:\n")
+    logger.info("Starting one-time edge migration:\n")
     logger.info(f"default timeout for API calls: {os.environ.get('HCS_TIMEOUT', 30)} seconds")
     if file:
-        logger.info(f"input file specified. file input takes the precedence. processing the file now")
+        logger.info("input file specified. file input takes the precedence. processing the file now")
         f = open(file)
         data = None
         try:
@@ -117,7 +116,7 @@ def migrate_edges(target_org_id: str, edge_ids: str, ca_label: str, verbose: boo
             )
             continue
 
-        logger.info(f"one-time edge migration on org_id: %s, edge_id: %s", target_org_id, edge_id)
+        logger.info("one-time edge migration on org_id: %s, edge_id: %s", target_org_id, edge_id)
         stats = dict()
         stats["org_id"] = target_org_id
         stats["edge_id"] = edge_id
@@ -126,10 +125,10 @@ def migrate_edges(target_org_id: str, edge_ids: str, ca_label: str, verbose: boo
         stats["is_fqdn_auto_generated"] = edge.get("fqdnAutoGenerated")
 
         try:
-            logger.info(f"performing one-time edge migration on org_id: %s, edge_id: %s", target_org_id, edge_id)
+            logger.info("performing one-time edge migration on org_id: %s, edge_id: %s", target_org_id, edge_id)
             # check if edge mqtt url is already migrated to omnissa on the edge
             edge_mqtt_url = data_util.deep_get_attr(edge, "fqdn", raise_on_not_found=False)
-            if edge.get("fqdnAutoGenerated") and edge.get("fqdnAutoGenerated") == True:
+            if edge.get("fqdnAutoGenerated") and edge.get("fqdnAutoGenerated") is True:
                 if ".omnissa." in edge_mqtt_url:
                     logger.warn(
                         f"Edge({edge_id}): edge mqtt url already updated with omnissa url {edge_mqtt_url}. Edge mqtt url update is skipped."
@@ -195,7 +194,7 @@ def migrate_edges(target_org_id: str, edge_ids: str, ca_label: str, verbose: boo
                 logger.info(f"Edge({edge_id}): PKI is updated with the caLabel {ca_label} for this edge")
                 stats["edge_pki_ca_label_mig_status"] = "MIGRATED"
                 stats["edge_pki_ca_label"] = ca_label
-                logger.info(f"sleep 7 minutes for cache refresh in PKI")
+                logger.info("sleep 7 minutes for cache refresh in PKI")
                 time.sleep(60 * 7)
 
             # perform uag twin sync operation
@@ -230,7 +229,7 @@ def migrate_edges(target_org_id: str, edge_ids: str, ca_label: str, verbose: boo
             stats["info"] = str(error)
             send_event(stats, HocStatus.FAILURE.value, verbose)
             return
-    logger.info(f"Finished one-time edge migration on org_id: %s", target_org_id)
+    logger.info("Finished one-time edge migration on org_id: %s", target_org_id)
 
 
 def refresh_certs_on_all_uag_vms(org_id: str, edge: dict, stats: dict, verbose: bool):
