@@ -16,4 +16,4 @@ limitations under the License.
 # Deprecated.
 # To be removed in the future.
 
-from ..template import *
+from ..template import action, create, delete, get, items, list, update, wait_for, wait_for_deleted, wait_for_ready
