@@ -1,2 +1,2 @@
 from .session import assign, deassign, logoff, sessions
-from .vm import get, list, raw_list, update
+from .vm import count, get, list, raw_list, update
