@@ -28,12 +28,12 @@ def _get_page(query_string):
     return _client.get(url)
 
 
-def list(**kwargs):
-    return PageRequest(_get_page, **kwargs).get()
+def list(fn_filter=None, **kwargs):
+    return PageRequest(_get_page, fn_filter, **kwargs).get()
 
 
-def items(**kwargs):
-    return PageRequest(_get_page, **kwargs).items()
+def items(fn_filter=None, **kwargs):
+    return PageRequest(_get_page, fn_filter, **kwargs).items()
 
 
 def get(org_id: str, **kwargs):
